# spey-pyhf

[![arxiv](https://img.shields.io/static/v1?style=plastic&label=arXiv&message=2307.06996%20%20[hep-ph]&color=brightgreen)](https://arxiv.org/abs/2307.06996)
[![DOI](https://img.shields.io/static/v1?style=plastic&label=DOI&message=TBA&color=blue)]()
[![zenodo](https://img.shields.io/static/v1?style=plastic&label=zenodo&message=TBA&color=blue)]()
[![doc](https://img.shields.io/static/v1?style=plastic&label&message=Online%20%20Documentation&logo=gitbook&logoColor=white&color=gray)](https://speysidehep.github.io/spey-pyhf/)

[![github](https://img.shields.io/static/v1?style=plastic&label&message=GitHub&logo=github&logoColor=black&color=white)](https://github.com/SpeysideHEP/spey-pyhf)
[![pypi](https://img.shields.io/static/v1?style=plastic&label&message=pypi%20%20package&logo=python&logoColor=yellow&color=blue)](https://pypi.org/project/spey-pyhf/)

``pyhf`` plugin for spey interface. This plug-in can be installed via

```bash
pip install spey-pyhf
```

command. Once installed ``spey`` interface will be able to automatically detect it.
For details on usage please see the [online documentation](https://speysidehep.github.io/spey-pyhf/).
